Взаимодействие с Last.fm
Пред. | Глава 3. Настройка | След.

## Взаимодействие с Last.fm

Взаимодействие с Last.fm двунаправленное: робот отправляет на сервер информацию о проигрываемых и «любимых» композициях, а от сервера получает информацию для коррекции имён исполнителей и свежую музыку. Чтобы всё это работало, в конфигурационный файл нужно добавить такой блок:

    last.fm:
      key: XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
      secret: XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
      login: alice
      password: secret

Параметры `key` и `secret` можно получить после регистрации собственного приложения (процедура бесплатна и занимает несколько минут).

Для включения скробблинга в конфигурационный файл следует добавить такую строку:

    last_fm_scrobble: true

Чтобы исключить из процесса скробблинга композиции с определёнными метками (например, джинглы), укажите их в параметре `last_fm_skip_labels` конфигурационного файла:

    last_fm_skip_labels: [jingle, quotes, news, special]

Наконец, чтобы знать, откуда пришла новая музыка, можно добавить к файлам, загруженным из Last.fm, специальные метки. Для этого их нужно указать в параметре `last_fm_add_labels` конфигурационного файла:

    last_fm_add_labels: [tagme, source:last.fm]

Пред. | Наверх | След.
Настройка синтезатора речи | Начало | Взаимодействие с Libre.fm